@@ -58,9 +58,6 @@ class TextNode:
     def __hash__(self) -> int:
         return hash(self.text)
 
-    def __str__(self) -> str:
-        return f'"{self.text}"'
-
 
 @dataclass
 class Node:
@@ -84,9 +81,6 @@ class Node:
             else:
                 yield child
 
-    def __str__(self) -> str:
-        return f"<{self.tag} />"
-
 
 class _Parser(HTMLParser):
     def __init__(self, root_el: str):
@@ -142,17 +136,10 @@ def unparse(node: Node) -> str:
         )
     )
     kids = "".join(
-        unparse(child)
-        if isinstance(child, Node)
-        else (
-            f'<span diff="{True}">{escape(child.text)}</span>'
-            if child.diff
-            else escape(child.text)
-        )
+        unparse(child) if isinstance(child, Node) else escape(child.text)
         for child in node.children
     )
     if node.tag in _VOID:
         return f"<{node.tag} {attrs}/>"
     else:
         return f"<{node.tag} {attrs}>{kids}</{node.tag}>"
-
